
# Slot: object




URI: [biolink:macromolecular_machine_to_biological_process_association_object](https://w3id.org/biolink/vocab/macromolecular_machine_to_biological_process_association_object)


## Domain and Range

[MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md) &#8594;  <sub>1..1</sub> [BiologicalProcess](BiologicalProcess.md)

## Parents

 *  is_a: [functional association➞object](functional_association_object.md)

## Children


## Used by

 * [MacromolecularMachineToBiologicalProcessAssociation](MacromolecularMachineToBiologicalProcessAssociation.md)
